aboutsummaryrefslogtreecommitdiff
path: root/metadata/metadata.proto
diff options
context:
space:
mode:
Diffstat (limited to 'metadata/metadata.proto')
-rw-r--r--metadata/metadata.proto20
1 files changed, 17 insertions, 3 deletions
diff --git a/metadata/metadata.proto b/metadata/metadata.proto
index 5e1b9dd..f2dd78f 100644
--- a/metadata/metadata.proto
+++ b/metadata/metadata.proto
@@ -19,15 +19,20 @@
* the License.
*/
-// If you modify this file, be sure to run "go generate" on this package.
+// If the *.proto file is modified, be sure to run "make gen" (at the project
+// root) to recreate the *.pb.go file.
syntax = "proto3";
package metadata;
+option go_package = "github.com/google/fscrypt/metadata";
+
// Cost parameters to be used in our hashing functions.
message HashingCosts {
int64 time = 2;
int64 memory = 3;
int64 parallelism = 4;
+ // If true, parallelism should no longer be truncated to 8 bits.
+ bool truncation_fixed = 5;
}
// This structure is used for our authenticated wrapping/unwrapping of keys.
@@ -63,7 +68,7 @@ message ProtectorData {
message EncryptionOptions {
int64 padding = 1;
// Type of encryption; should match declarations of unix.FS_ENCRYPTION_MODE
enum Mode {
default = 0;
AES_256_XTS = 1;
@@ -72,10 +77,14 @@ message EncryptionOptions {
AES_256_CTS = 4;
AES_128_CBC = 5;
AES_128_CTS = 6;
+ Adiantum = 9;
+ AES_256_HCTR2 = 10;
}
Mode contents = 2;
Mode filenames = 3;
+
+ int64 policy_version = 4;
}
message WrappedPolicyKey {
@@ -94,6 +103,11 @@ message PolicyData {
message Config {
SourceType source = 1;
HashingCosts hash_costs = 2;
- string compatibility = 3;
EncryptionOptions options = 4;
+ bool use_fs_keyring_for_v1_policies = 5;
+ bool allow_cross_user_metadata = 6;
+
+ // reserve the removed field 'string compatibility = 3;'
+ reserved 3;
+ reserved "compatibility";
}
@@ -63,7 +68,7 @@ message ProtectorData {
message EncryptionOptions {
int64 padding = 1;
- // Type of encryption; should match declarations of unix.FS_ENCRYPTION_MODE
+ // Type of encryption; should match declarations of unix.FSCRYPT_MODE
enum Mode {
default = 0;